texto = """Atenção,

Este diretório de instalação `pip` recentemente caiu em desuso e não é mais mantida. Para continuar a aproveitar os recursos mais recentes e receber suporte ativo, recomendamos que você migre para a nova biblioteca.

Você pode encontrar a biblioteca atualizada no seguinte link: https://github.com/DevLucasLourenco/AllWhatsPy.
Ou utilizar: pip install -U allwhatspy-awp

Certifique-se de atualizar seu ambiente e código para usar a versão mais recente. Se você tiver alguma dúvida ou precisar de assistência, não hesite em entrar em contato conosco.

Obrigado por sua compreensão e por escolher usar a versão atualizada da biblioteca.

Atenciosamente,
DevLucasLourenco"""

print(texto)


from setuptools import setup

setup(name='allwhatspy',
    version='0.2.00.6',
    license='MIT License',
    author='Lucas Lourenço',
    long_description='Descontinuado. Utilize pip install -U allwhatspy-awp',
    long_description_content_type="text/markdown",
    author_email='dev.lucaslourenco@gmail.com',
    keywords='descontinuado',
    description=u'Descontinuado. Utilize pip install -U allwhatspy-awp',
    packages=['AllWhatsPy'],
    install_requires=['webdriver-manager', 'selenium', 'requests'],)